import { ChartD3Service } from '../../services/chart.d3.service';
export class ChartEvents {
    constructor(primarySeries, anjHover, chartService, popover) {
        this.primarySeries = primarySeries;
        this.anjHover = anjHover;
        this.chartService = chartService;
        this.popover = popover;
    }
    // Component Event Handlers
    anjLineOverlayHoverHandler(svg, data, x, axisConfigs, seriesMeta) {
        this.clearTimeouts();
        const targetData = this.chartService.getTargetingData(data);
        const dataIndex = ChartD3Service.getIndexOfClosestPoint(x, targetData);
        if (this.activeIndex !== dataIndex) {
            this.setPopoverData(dataIndex, data, axisConfigs, seriesMeta);
            this.displayPopover(svg, this.activeIndex, true);
        }
    }
    anjColumnOverlayHoverHandler(svg, data, x, axisConfigs, seriesMeta) {
        this.clearTimeouts();
        const indexQuery = ChartD3Service.getIndexOfClosestBar(x, data);
        const columnGroup = indexQuery.segment;
        data = [data[columnGroup]];
        this.hydrateDisplayColumnPopover(svg, indexQuery, data, axisConfigs, seriesMeta);
    }
    anjStackedOverlayHoverHandler(svg, data, x, axisConfigs, seriesMeta) {
        this.clearTimeouts();
        const indexQuery = ChartD3Service.getIndexOfClosestSingleSeriesBar(x, data);
        this.hydrateDisplayColumnPopover(svg, indexQuery, data, axisConfigs, seriesMeta);
    }
    anjSVGHoverHandler(targetEl, data, dataIndex, axisConfigs, seriesMeta, seriesIndex) {
        this.clearTimeouts();
        this.setPopoverData(dataIndex, [data], axisConfigs, seriesMeta, seriesIndex);
        this.displayPopover(targetEl);
    }
    anjEndHoverHandler(svg) {
        this.svgExitTimer = setTimeout(() => {
            this.hidePopover(svg);
        }, ChartEvents.popoverDebounceLength);
    }
    // Popover controllers
    displayPopover(svg, activeIndex, focus) {
        const popoverEl = (!isNaN(activeIndex)) ? this.chartService.getPopoverEl(svg, activeIndex) : svg;
        this.display(popoverEl);
        if (focus) {
            ChartD3Service.showFocus(svg, activeIndex);
        }
    }
    async display(target) {
        if (!target) {
            return;
        }
        const popper = await this.popover.popper();
        if (popper) {
            popper.reference = target;
            popper.scheduleUpdate();
        }
        else {
            this.popover.open(target);
        }
    }
    hidePopover(svg) {
        this.activeIndex = null;
        this.popover.close();
        if (svg) {
            ChartD3Service.hideFocus(svg);
        }
    }
    popoverHoverEnd(e, ids) {
        this.clearTimeouts();
        const notOurChart = !e.relatedTarget.closest(`#${ids.chartId}`) && !e.relatedTarget.closest(`#${ids.overlayId}`);
        const ourChartSVG = e.relatedTarget.tagName === 'svg';
        if (notOurChart || ourChartSVG) {
            this.popoverExitTimer = setTimeout(() => {
                this.hidePopover();
            }, ChartEvents.popoverDebounceLength);
        }
    }
    popoverHoverStart() {
        this.clearTimeouts();
    }
    setPopoverData(dataIndex, data, axisConfigs, seriesMeta, seriesIndex) {
        this.activeIndex = dataIndex;
        const seriesStyle = this.chartService.getPopoverSeriesStyle();
        const activeData = { data, axisConfigs, activeIndex: this.activeIndex, seriesStyle, seriesMeta, seriesIndex };
        this.anjHover.emit(activeData);
    }
    hydrateDisplayColumnPopover(svg, indexQuery, data, axisConfigs, seriesMeta) {
        if (this.activeIndex !== indexQuery.displayIndex && indexQuery.displayIndex > -1) {
            this.setPopoverData(indexQuery.dataIndex, data, axisConfigs, seriesMeta);
            this.activeIndex = indexQuery.displayIndex;
            this.displayPopover(svg, this.activeIndex, true);
        }
    }
    clearTimeouts() {
        clearTimeout(this.svgExitTimer);
        clearTimeout(this.popoverExitTimer);
    }
}
ChartEvents.popoverDebounceLength = 150;
