export interface ActiveData {
    activeIndex: number;
    axisConfigs: AxisConfigs;
    data: CoordinateData[][];
    seriesStyle: SeriesStyle;
    seriesMeta: SeriesMeta[];
    seriesIndex?: number;
}
export interface AxisConfig {
    showAxis?: boolean;
    showTicks?: boolean;
    labelType?: FormatType;
    formattingOptions?: DataFormattingOptions;
    formatter?: (v: any) => string;
}
export interface AxisConfigs {
    x: AxisConfig;
    y: AxisConfig;
}
export interface ChartIds {
    chartId: string;
    overlayId: string;
}
export interface ChartStyle {
    stroke?: string | string[];
    fill?: string | string[];
    aggregateLineColor?: string;
}
export interface CoordinateData {
    x: string | Date | number;
    y: string | number;
    drilldown?: CoordinateData[];
}
export interface DataFormattingOptions {
    locale?: string;
    currency?: string;
}
export interface Delta {
    value: number;
    period: any;
}
export interface Dims {
    height: number;
    width: number;
    margin?: {
        top?: number;
        bottom?: number;
        left?: number;
        right?: number;
    };
}
export interface IndexQuery {
    dataIndex: number;
    displayIndex: number;
    segment: number;
}
export interface PointOptions {
    opacity: number;
    fill?: string;
    radius: number;
}
export interface SeriesHierarchy {
    primarySeries: SeriesType;
    secondarySeries?: SeriesType;
    primaryComponents: HTMLAnjSeriesElement[];
    secondaryComponents?: HTMLAnjSeriesElement[];
}
export interface SeriesMeta {
    color: string;
    name: string;
}
export declare enum SeriesStyle {
    Multi = 0,
    Single = 1
}
export declare enum SeriesType {
    Line = "line",
    Column = "column",
    Pie = "pie",
    Stacked = "stacked",
    Scatter = "scatter"
}
export declare enum TimeInterval {
    Monthly = "monthly",
    Yearly = "yearly",
    Weekly = "weeks",
    Daily = "daily",
    Quarterly = "quarterly"
}
export declare type AxisDimension = 'x' | 'y';
export declare type FormatType = 'date' | 'number' | 'string' | 'percent' | 'currency';
